@@ -1,6 +1,9 @@
 package MooseX::Types::TypeDecorator;
 {
-  $MooseX::Types::TypeDecorator::VERSION = '0.30';
+  $MooseX::Types::TypeDecorator::VERSION = '0.41';
+}
+BEGIN {
+  $MooseX::Types::TypeDecorator::AUTHORITY = 'cpan:PHAYLON';
 }
 
 #ABSTRACT: Wraps Moose::Meta::TypeConstraint objects with added features
@@ -19,17 +22,19 @@ use overload(
             my $tc = $self->{__type_constraint};
             return 0+$tc;
      },
+    # workaround for perl 5.8.5 bug
+    '==' => sub { 0+$_[0] == 0+$_[1] },
     '""' => sub {
-    		my $self = shift @_;
-    		if(blessed $self) {
-        		return $self->__type_constraint->name;     		
-    		} else {
-    			return "$self";
-    		}
+            my $self = shift @_;
+            if(blessed $self) {
+                return $self->__type_constraint->name;
+            } else {
+                return "$self";
+            }
     },
     bool => sub { 1 },
     '|' => sub {
-        
+
         ## It's kind of ugly that we need to know about Union Types, but this
         ## is needed for syntax compatibility.  Maybe someday we'll all just do
         ## Or[Str,Str,Int]
@@ -43,7 +48,7 @@ use overload(
 
         ( scalar @tc == scalar @args)
             || __PACKAGE__->_throw_error(
-			  "one of your type constraints is bad.  Passed: ". join(', ', @args) ." Got: ". join(', ', @tc));
+              "one of your type constraints is bad.  Passed: ". join(', ', @args) ." Got: ". join(', ', @tc));
 
         ( scalar @tc >= 2 )
             || __PACKAGE__->_throw_error("You must pass in at least 2 type names to make a union");
@@ -52,18 +57,22 @@ use overload(
         return Moose::Util::TypeConstraints::register_type_constraint($union);
     },
     fallback => 1,
-    
+
 );
 
 
 sub new {
-    my $class = shift @_;
+    my $proto = shift;
+    if (ref($proto)) {
+        return $proto->_try_delegate('new', @_);
+    }
+    my $class = $proto;
     if(my $arg = shift @_) {
         if(blessed $arg && $arg->isa('Moose::Meta::TypeConstraint')) {
             return bless {'__type_constraint'=>$arg}, $class;
         } elsif(
             blessed $arg &&
-            $arg->isa('MooseX::Types::UndefinedType') 
+            $arg->isa('MooseX::Types::UndefinedType')
           ) {
             ## stub in case we'll need to handle these types differently
             return bless {'__type_constraint'=>$arg}, $class;
@@ -73,18 +82,18 @@ sub new {
             __PACKAGE__->_throw_error("Argument cannot be '$arg'");
         }
     } else {
-        __PACKAGE__->_throw_error("This method [new] requires a single argument.");        
+        __PACKAGE__->_throw_error("This method [new] requires a single argument.");
     }
 }
 
 
 sub __type_constraint {
-    my $self = shift @_;    
+    my $self = shift @_;
     if(blessed $self) {
         if(defined(my $tc = shift @_)) {
             $self->{__type_constraint} = $tc;
         }
-        return $self->{__type_constraint};        
+        return $self->{__type_constraint};
     } else {
         __PACKAGE__->_throw_error('cannot call __type_constraint as a class method');
     }
@@ -92,39 +101,21 @@ sub __type_constraint {
 
 
 sub isa {
-    my ($self, $target) = @_;  
-    if(defined $target) {
-    	if(blessed $self) {
-    		return $self->__type_constraint->isa($target);
-    	} else {
-    		return;
-    	}
-    } else {
-        return;
-    }
+  my $self = shift;
+  return
+    blessed $self
+      ? $self->__type_constraint->isa(@_)
+      || $self->_try_delegate( 'isa', @_ )
+      : $self->SUPER::isa(@_);
 }
 
 
-
 sub can {
-    my ($self, $target) = @_;
-    if(defined $target) {
-    	if(blessed $self) {
-    		return $self->__type_constraint->can($target);
-    	} else {
-    		return;
-    	}
-    } else {
-        return;
-    }
-}
+    my $self = shift;
 
-
-sub meta {
-	my $self = shift @_;
-	if(blessed $self) {
-		return $self->__type_constraint->meta;
-	} 
+    return blessed $self
+        ? $self->_try_delegate( 'can', @_ )
+        : $self->SUPER::can(@_);
 }
 
 
@@ -142,37 +133,69 @@ sub DESTROY {
 
 
 sub AUTOLOAD {
-    
     my ($self, @args) = @_;
     my ($method) = (our $AUTOLOAD =~ /([^:]+)$/);
-    
+
     ## We delegate with this method in an attempt to support a value of
     ## __type_constraint which is also AUTOLOADing, in particular the class
     ## MooseX::Types::UndefinedType which AUTOLOADs during autovivication.
-    
-    my $return;
-    eval {
-        $return = $self->__type_constraint->$method(@args);
-    }; if($@) {
-        __PACKAGE__->_throw_error($@);
-    } else {
-        return $return;
+
+    $self->_try_delegate($method, @args);
+}
+
+sub _try_delegate {
+    my ($self, $method, @args) = @_;
+    my $tc = $self->__type_constraint;
+    my $class;
+    if ($tc->can('is_subtype_of')) { # Union can't
+        my $search_tc = $tc;
+        while (1) {
+            if ($search_tc->isa('Moose::Meta::TypeConstraint::Class')) {
+                $class = $search_tc->class;
+                last;
+            }
+            $search_tc = $search_tc->parent;
+            last unless $search_tc && $search_tc->is_subtype_of('Object');
+        }
     }
+
+    my $inv = do {
+        if ($method eq 'new') {
+            die "new called on type decorator for non-class-type ".$tc->name
+                unless $class;
+            die "new called on class type decorator ".$tc->name."\n"
+                ." for class ${class}\n"
+                ." which does not provide a new method - did you forget to load it?"
+                unless $class->can('new');
+            $class
+        } elsif ($class && !$tc->can($method)) {
+            $class
+        } else {
+            $tc
+        }
+    };
+
+    $inv->$method(@args);
 }
 
 
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
+=for :stopwords Robert "phaylon" Sedlacek
+
 =head1 NAME
 
 MooseX::Types::TypeDecorator - Wraps Moose::Meta::TypeConstraint objects with added features
 
 =head1 VERSION
 
-version 0.30
+version 0.41
 
 =head1 DESCRIPTION
 
@@ -191,18 +214,15 @@ Old school instantiation
 
 Set/Get the type_constraint.
 
-=head2 isa
+=head2 C<isa>
 
-handle $self->isa since AUTOLOAD can't.
+handle C<< $self->isa >> since C<AUTOLOAD> can't - this tries both the type constraint,
+and for a class type, the class.
 
 =head2 can
 
 handle $self->can since AUTOLOAD can't.
 
-=head2 meta
-
-have meta examine the underlying type constraints
-
 =head2 _throw_error
 
 properly delegate error messages
@@ -213,7 +233,11 @@ We might need it later
 
 =head2 AUTOLOAD
 
-Delegate to the decorator target.
+Delegate to the decorator target, unless this is a class type, in which
+case it will try to delegate to the type object, then if that fails try
+the class. The method 'new' is special cased to only be permitted on
+the class; if there is no class, or it does not provide a new method,
+an exception will be thrown.
 
 =head1 LICENSE
 
@@ -226,10 +250,9 @@ Robert "phaylon" Sedlacek <rs@474.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Robert "phaylon" Sedlacek.
+This software is copyright (c) 2007 by Robert "phaylon" Sedlacek.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
