@@ -1,6 +1,9 @@
 package MooseX::Types::Wrapper;
 {
-  $MooseX::Types::Wrapper::VERSION = '0.30';
+  $MooseX::Types::Wrapper::VERSION = '0.41';
+}
+BEGIN {
+  $MooseX::Types::Wrapper::AUTHORITY = 'cpan:PHAYLON';
 }
 
 #ABSTRACT: Wrap exports from a library
@@ -8,9 +11,9 @@ package MooseX::Types::Wrapper;
 use Moose;
 
 use Carp::Clan      qw( ^MooseX::Types );
-use Class::MOP;
+use Module::Runtime 'use_module';
 
-use namespace::clean -except => [qw( meta )];
+use namespace::autoclean;
 
 extends 'MooseX::Types';
 
@@ -24,11 +27,11 @@ sub import {
         croak qq($class expects an array reference as import spec)
             unless ref $libraries{ $l } eq 'ARRAY';
 
-        my $library_class 
+        my $library_class
           = ($l eq 'Moose' ? 'MooseX::Types::Moose' : $l );
-        Class::MOP::load_class($library_class);
+        use_module($library_class);
 
-        $library_class->import({ 
+        $library_class->import({
             -into    => scalar(caller),
             -wrapper => $class,
         }, @{ $libraries{ $l } });
@@ -38,17 +41,21 @@ sub import {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
+=for :stopwords Robert "phaylon" Sedlacek
+
 =head1 NAME
 
 MooseX::Types::Wrapper - Wrap exports from a library
 
 =head1 VERSION
 
-version 0.30
+version 0.41
 
 =head1 DESCRIPTION
 
@@ -73,10 +80,9 @@ Robert "phaylon" Sedlacek <rs@474.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Robert "phaylon" Sedlacek.
+This software is copyright (c) 2007 by Robert "phaylon" Sedlacek.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
